==> merlin_utils-0.0.19.tar.gz: merlin_utils-0.0.19/merlin_utils/util.py <==
import copy
import logging
import os
import re
from datetime import datetime
from functools import wraps

from flask import request
from flask_api import status
from google.auth.transport import requests
from google.cloud.datastore import Entity
from google.oauth2 import id_token
from uuid import uuid4

HTTP_REQUEST = requests.Request()
PROJECT_ID = os.environ.get('PROJECT')
UNAUTH = {"Message": "User has not permissions"}, status.HTTP_401_UNAUTHORIZED


def firebase_auth(f):
    @wraps(f)
    def wrapped(*args, **kwargs):
        id_token_firebase = request.headers.get('Authorization')
        if not id_token_firebase:
            return UNAUTH
        try:
            claims = id_token.verify_firebase_token(id_token_firebase.split(' ').pop(), HTTP_REQUEST)
        except Exception as ex:
            logging.warning(ex)
            return UNAUTH
        logging.info(claims)
        if not (claims.get('aud') == PROJECT_ID or claims.get('iss') == os.environ.get('ISSUER') % PROJECT_ID):
            return UNAUTH
        kwargs["auth_user"] = {"id": claims.get('sub'), "role": claims.get('role')}
        return f(*args, **kwargs)

    return wrapped


def pre_loader(in_data):
    if in_data is not None:
        if isinstance(in_data, Entity):
            in_data["key"] = in_data.key
        for key, value in copy.deepcopy(in_data).items():
            if isinstance(value, datetime):
                in_data[key] = value.isoformat()
            elif value is None:
                in_data.pop(key)


def validate_email(email):
    if email is not None:
        return email.split("@")[0] if re.fullmatch(
            "^[_a-z0-9-+]+(\.[_a-z0-9-]+)*@[a-z0-9-+]+(\.[a-z0-9-]+)*(\.[a-z]{2,4})$", email) is not None else None


def build_statistic_event(event, id_user, role, id_receptor=None, id_job=None, extra_params=None):
    statistic_event = {
        "idEvent": str(uuid4()),
        "idUser": id_user,
        "userRole": role,
        **event
    }
    if id_receptor:
        id_receptor_name = "idUserCandidate " if role == "Candidate" else "idUserEmployer"
        statistic_event[id_receptor_name] = id_receptor
    if extra_params:
        statistic_event["properties"].update(extra_params)
    if id_job:
        statistic_event["idJob"] = id_job

    return {"event": statistic_event, "appsflyer": statistic_event.get("appsflyer")}


def emails_substitutions(substitutions, id_user):
    emails_substitutions = {
        "{{ asm_group_unsubscribe_raw_url }}": "www.merlinjobs.com/unsubscribe?id={}".format(id_user),
        "{{ unsubscribe_sendgrid_default }}": "<%asm_group_unsubscribe_raw_url%>",
        "https://www.merlinjobs.com/": "https://www.merlinjobs.com/" if PROJECT_ID == "merlin-pro" else "https"
                                                                                                        "://merlin-qa."
                                                                                                        "appspot.com/ ",
        **substitutions
    }
    return emails_substitutions

==> merlin_utils-0.0.20.tar.gz: merlin_utils-0.0.20/merlin_utils/util.py <==
import copy
import logging
import os
import re
from datetime import datetime
from functools import wraps

from flask import request
from flask_api import status
from google.auth.transport import requests
from google.cloud.datastore import Entity
from google.oauth2 import id_token
from uuid import uuid4

HTTP_REQUEST = requests.Request()
PROJECT_ID = os.environ.get('PROJECT')
UNAUTH = {"Message": "User has not permissions"}, status.HTTP_401_UNAUTHORIZED


def firebase_auth(f):
    @wraps(f)
    def wrapped(*args, **kwargs):
        id_token_firebase = request.headers.get('Authorization')
        if not id_token_firebase:
            return UNAUTH
        try:
            claims = id_token.verify_firebase_token(id_token_firebase.split(' ').pop(), HTTP_REQUEST)
        except Exception as ex:
            logging.warning(ex)
            return UNAUTH
        logging.info(claims)
        if not (claims.get('aud') == PROJECT_ID or claims.get('iss') == os.environ.get('ISSUER') % PROJECT_ID):
            return UNAUTH
        kwargs["auth_user"] = {"id": claims.get('sub'), "role": claims.get('role')}
        return f(*args, **kwargs)

    return wrapped


def pre_loader(in_data):
    if in_data is not None:
        if isinstance(in_data, Entity):
            in_data["key"] = in_data.key
        for key, value in copy.deepcopy(in_data).items():
            if isinstance(value, datetime):
                in_data[key] = value.isoformat()
            elif value is None:
                in_data.pop(key)


def validate_email(email):
    if email is not None:
        return email.split("@")[0] if re.fullmatch(
            "^[_a-z0-9-+]+(\.[_a-z0-9-]+)*@[a-z0-9-+]+(\.[a-z0-9-]+)*(\.[a-z]{2,4})$", email) is not None else None


def build_statistic_event(event, id_user, role, id_receptor=None, id_job=None, extra_params=None):
    statistic_event = {
        "idEvent": str(uuid4()),
        "idUser": id_user,
        "userRole": role,
        **event
    }
    if id_receptor:
        id_receptor_name = "idUserCandidate " if role == "Candidate" else "idUserEmployer"
        statistic_event[id_receptor_name] = id_receptor
    if extra_params:
        statistic_event["properties"].update(extra_params)
    if id_job:
        statistic_event["idJob"] = id_job

    return {"event": statistic_event, "appsflyer": statistic_event.get("appsflyer")}


def emails_substitutions(substitutions, id_user):
    emails_substitution = {
        "{{ asm_group_unsubscribe_raw_url }}": "www.merlinjobs.com/unsubscribe?id={}".format(id_user),
        "{{ unsubscribe_sendgrid_default }}": "<%asm_group_unsubscribe_raw_url%>",
        "https://www.merlinjobs.com/": "https://www.merlinjobs.com/" if PROJECT_ID == "merlin-pro" else "https"
                                                                                                        "://merlin-qa."
                                                                                                        "appspot.com/ ",
        **substitutions
    }
    return emails_substitution
